<?php

/**
 * Vvveb
 *
 * Copyright (C) 2022  Ziadin Givan
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

/*
Name: Stripe payment gateway
Slug: stripe
Category: payment
Url: https://www.vvveb.com
Description: Stripe payment method
Author: givanz
Version: 0.1
Thumb: stripe.svg
Author url: https://www.vvveb.com
Settings: /admin/index.php?module=plugins/stripe/settings
*/

use function Vvveb\getSetting;
use Vvveb\Plugins\Stripe\Payment;
use Vvveb\System\Core\Request;
use Vvveb\System\Core\View;
use Vvveb\System\Event;
use Vvveb\System\Payment as PaymentApi;
use Vvveb\System\Routes;

if (! defined('V_VERSION')) {
	die('Invalid request!');
}

class Stripe {
	private $view;

	function charge($checkoutInfo, $order_id, $site) {
		$request = Request::getInstance();
		$token   = $request->post['stripeToken'];
		$card    = $request->post['card'] ?? '';

		if ($token) {
			require_once __DIR__ . '/stripe-php/init.php';

			\Stripe\Stripe::setEnableTelemetry(false);
			\Stripe\Stripe::setAppInfo('Vvveb', V_VERSION, 'https://vvveb.com');

			$domain   = $site['title'] ?? 'vvveb';
			$currency = $checkoutInfo['currency'];
			//stripe amount must be in cents so multiply with 100
			$amount = intval(round(floatval($checkoutInfo['total']), 2) * 100);

			$data = [
				'amount'      => intval($amount),
				'currency'    => $currency,
				'card'        => $token ? $token : $card,
				'description' => "Order #$order_id on $domain",
			];

			$settings = getSetting('stripe', []);

			\Stripe\Stripe::setApiKey($settings['secret_key'] ?? '');
			$charge = \Stripe\Charge::create($data);

			if ($charge && is_array($charge)) {
				$success = ($charge['status'] == 'succeeded');
				$receipt = $charge['receipt_url'];

				$checkoutInfo['payment_data'] = json_encode($charge);
			}
		}

		return [$checkoutInfo, $order_id, $site];
	}

	function admin() {
	}

	function app() {
		Routes::addRoute('/stripe-ipn', ['module' => 'plugins/stripe/index/ipn']);
		Routes::addRoute('/stripe', ['module' => 'plugins/stripe/index/index']);

		$routes  = [
			'checkout/checkout/index',
		];

		$config             = getSetting('stripe');
		$this->view->stripe = $config;

		Event::on('Vvveb\System\Core\View', 'compile', __CLASS__, function ($template, $htmlFile, $tplFile, $vTpl, $view) use ($routes) {
			// add stripe js and keys to checkout page
			if ($url = Routes::getUrlData()) {
				if (in_array($url['route'], $routes)) {
					$vTpl->loadTemplateFile(__DIR__ . '/app/template/common.tpl');
				}
			}

			return [$template, $htmlFile, $tplFile, $vTpl, $view];
		});

		Event::on('Vvveb\Controller\Checkout\Checkout', 'add:after', __CLASS__, [$this, 'charge']);
	}

	function __construct() {
		if (Vvveb\isEditor()) {
			return;
		}

		$this->view = View::getInstance();
		$payment    = PaymentApi::getInstance();
		$payment->registerMethod('stripe', Payment::class);

		if (APP == 'admin') {
			$this->admin();
		} else {
			if (APP == 'app') {
				$this->app();
			}
		}
	}
}

$stripe = new Stripe();
