<?php

/**
 * Vvveb
 *
 * Copyright (C) 2022  Ziadin Givan
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

namespace Stripe\ApiOperations;

/**
 * Trait for creatable resources. Adds a `create()` static method to the class.
 *
 * This trait should only be applied to classes that derive from StripeObject.
 */
trait Create {
	/**
	 * @param null|array $params
	 * @param null|array|string $options
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return static the created resource
	 */
	public static function create($params = null, $options = null) {
		self::_validateParams($params);
		$url = static::classUrl();

		list($response, $opts) = static::_staticRequest('post', $url, $params, $options);
		$obj                   = \Stripe\Util\Util::convertToStripeObject($response->json, $opts);
		$obj->setLastResponse($response);

		return $obj;
	}
}
