<?php

/**
 * Vvveb
 *
 * Copyright (C) 2022  Ziadin Givan
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

namespace Stripe\ApiOperations;

/**
 * Trait for retrievable singleton resources. Adds a `retrieve()` static method to the
 * class.
 *
 * This trait should only be applied to classes that derive from SingletonApiResource.
 */
trait SingletonRetrieve {
	/**
	 * @param null|array|string $opts the ID of the API resource to retrieve,
	 *     or an options array containing an `id` key
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return static
	 */
	public static function retrieve($opts = null) {
		$opts     = \Stripe\Util\RequestOptions::parse($opts);
		$instance = new static(null, $opts);
		$instance->refresh();

		return $instance;
	}
}
