<?php

/**
 * Vvveb
 *
 * Copyright (C) 2022  Ziadin Givan
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

namespace Stripe;

/**
 * Interface for a Stripe client.
 */
interface BaseStripeClientInterface {
	/**
	 * Gets the API key used by the client to send requests.
	 *
	 * @return null|string the API key used by the client to send requests
	 */
	public function getApiKey();

	/**
	 * Gets the client ID used by the client in OAuth requests.
	 *
	 * @return null|string the client ID used by the client in OAuth requests
	 */
	public function getClientId();

	/**
	 * Gets the base URL for Stripe's API.
	 *
	 * @return string the base URL for Stripe's API
	 */
	public function getApiBase();

	/**
	 * Gets the base URL for Stripe's OAuth API.
	 *
	 * @return string the base URL for Stripe's OAuth API
	 */
	public function getConnectBase();

	/**
	 * Gets the base URL for Stripe's Files API.
	 *
	 * @return string the base URL for Stripe's Files API
	 */
	public function getFilesBase();
}
