<?php

/**
 * Vvveb
 *
 * Copyright (C) 2022  Ziadin Givan
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

namespace Stripe\Exception;

/**
 * InvalidRequestException is thrown when a request is initiated with invalid
 * parameters.
 */
class InvalidRequestException extends ApiErrorException {
	protected $stripeParam;

	/**
	 * Creates a new InvalidRequestException exception.
	 *
	 * @param string $message the exception message
	 * @param null|int $httpStatus the HTTP status code
	 * @param null|string $httpBody the HTTP body as a string
	 * @param null|array $jsonBody the JSON deserialized body
	 * @param null|array|\Stripe\Util\CaseInsensitiveArray $httpHeaders the HTTP headers array
	 * @param null|string $stripeCode the Stripe error code
	 * @param null|string $stripeParam the parameter related to the error
	 *
	 * @return InvalidRequestException
	 */
	public static function factory(
		$message,
		$httpStatus = null,
		$httpBody = null,
		$jsonBody = null,
		$httpHeaders = null,
		$stripeCode = null,
		$stripeParam = null
	) {
		$instance = parent::factory($message, $httpStatus, $httpBody, $jsonBody, $httpHeaders, $stripeCode);
		$instance->setStripeParam($stripeParam);

		return $instance;
	}

	/**
	 * Gets the parameter related to the error.
	 *
	 * @return null|string
	 */
	public function getStripeParam() {
		return $this->stripeParam;
	}

	/**
	 * Sets the parameter related to the error.
	 *
	 * @param null|string $stripeParam
	 */
	public function setStripeParam($stripeParam) {
		$this->stripeParam = $stripeParam;
	}
}
