<?php

/**
 * Vvveb
 *
 * Copyright (C) 2022  Ziadin Givan
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

namespace Stripe\Exception;

/**
 * SignatureVerificationException is thrown when the signature verification for
 * a webhook fails.
 */
class SignatureVerificationException extends \Exception implements ExceptionInterface {
	protected $httpBody;

	protected $sigHeader;

	/**
	 * Creates a new SignatureVerificationException exception.
	 *
	 * @param string $message the exception message
	 * @param null|string $httpBody the HTTP body as a string
	 * @param null|string $sigHeader the `Stripe-Signature` HTTP header
	 *
	 * @return SignatureVerificationException
	 */
	public static function factory(
		$message,
		$httpBody = null,
		$sigHeader = null
	) {
		$instance = new static($message);
		$instance->setHttpBody($httpBody);
		$instance->setSigHeader($sigHeader);

		return $instance;
	}

	/**
	 * Gets the HTTP body as a string.
	 *
	 * @return null|string
	 */
	public function getHttpBody() {
		return $this->httpBody;
	}

	/**
	 * Sets the HTTP body as a string.
	 *
	 * @param null|string $httpBody
	 */
	public function setHttpBody($httpBody) {
		$this->httpBody = $httpBody;
	}

	/**
	 * Gets the `Stripe-Signature` HTTP header.
	 *
	 * @return null|string
	 */
	public function getSigHeader() {
		return $this->sigHeader;
	}

	/**
	 * Sets the `Stripe-Signature` HTTP header.
	 *
	 * @param null|string $sigHeader
	 */
	public function setSigHeader($sigHeader) {
		$this->sigHeader = $sigHeader;
	}
}
