<?php

/**
 * Vvveb
 *
 * Copyright (C) 2022  Ziadin Givan
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

namespace Stripe\HttpClient;

interface ClientInterface {
	/**
	 * @param 'delete'|'get'|'post' $method The HTTP method being used
	 * @param string $absUrl The URL being requested, including domain and protocol
	 * @param array $headers Headers to be used in the request (full strings, not KV pairs)
	 * @param array $params KV pairs for parameters. Can be nested for arrays and hashes
	 * @param bool $hasFile Whether or not $params references a file (via an @ prefix or
	 *                         CURLFile)
	 * @param 'preview'|'standard' $apiMode
	 *
	 * @throws \Stripe\Exception\ApiConnectionException
	 * @throws \Stripe\Exception\UnexpectedValueException
	 *
	 * @return array an array whose first element is raw request body, second
	 *    element is HTTP status code and third array of HTTP headers
	 */
	public function request($method, $absUrl, $headers, $params, $hasFile, $apiMode = 'standard');
}
