<?php

/**
 * Vvveb
 *
 * Copyright (C) 2022  Ziadin Givan
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

namespace Stripe\Service;

class BalanceTransactionService extends \Stripe\Service\AbstractService {
	/**
	 * Returns a list of transactions that have contributed to the Stripe account
	 * balance (e.g., charges, transfers, and so forth). The transactions are returned
	 * in sorted order, with the most recent transactions appearing first.
	 *
	 * Note that this endpoint was previously called “Balance history” and used the
	 * path <code>/v1/balance/history</code>.
	 *
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Collection<\Stripe\BalanceTransaction>
	 */
	public function all($params = null, $opts = null) {
		return $this->requestCollection('get', '/v1/balance_transactions', $params, $opts);
	}

	/**
	 * Retrieves the balance transaction with the given ID.
	 *
	 * Note that this endpoint previously used the path
	 * <code>/v1/balance/history/:id</code>.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\BalanceTransaction
	 */
	public function retrieve($id, $params = null, $opts = null) {
		return $this->request('get', $this->buildPath('/v1/balance_transactions/%s', $id), $params, $opts);
	}
}
