<?php

/**
 * Vvveb
 *
 * Copyright (C) 2022  Ziadin Givan
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

namespace Stripe\Service\Capital;

class FinancingOfferService extends \Stripe\Service\AbstractService {
	/**
	 * Retrieves the financing offers available for Connected accounts that belong to
	 * your platform.
	 *
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Collection<\Stripe\Capital\FinancingOffer>
	 */
	public function all($params = null, $opts = null) {
		return $this->requestCollection('get', '/v1/capital/financing_offers', $params, $opts);
	}

	/**
	 * Acknowledges that platform has received and delivered the financing_offer to the
	 * intended merchant recipient.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Capital\FinancingOffer
	 */
	public function markDelivered($id, $params = null, $opts = null) {
		return $this->request('post', $this->buildPath('/v1/capital/financing_offers/%s/mark_delivered', $id), $params, $opts);
	}

	/**
	 * Get the details of the financing offer.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Capital\FinancingOffer
	 */
	public function retrieve($id, $params = null, $opts = null) {
		return $this->request('get', $this->buildPath('/v1/capital/financing_offers/%s', $id), $params, $opts);
	}
}
