<?php

/**
 * Vvveb
 *
 * Copyright (C) 2022  Ziadin Givan
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

namespace Stripe\Service;

class EventService extends \Stripe\Service\AbstractService {
	/**
	 * List events, going back up to 30 days. Each event data is rendered according to
	 * Stripe API version at its creation time, specified in <a
	 * href="/docs/api/events/object">event object</a> <code>api_version</code>
	 * attribute (not according to your current Stripe API version or
	 * <code>Stripe-Version</code> header).
	 *
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Collection<\Stripe\Event>
	 */
	public function all($params = null, $opts = null) {
		return $this->requestCollection('get', '/v1/events', $params, $opts);
	}

	/**
	 * Retrieves the details of an event. Supply the unique identifier of the event,
	 * which you might have received in a webhook.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Event
	 */
	public function retrieve($id, $params = null, $opts = null) {
		return $this->request('get', $this->buildPath('/v1/events/%s', $id), $params, $opts);
	}
}
