<?php

/**
 * Vvveb
 *
 * Copyright (C) 2022  Ziadin Givan
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

namespace Stripe\Service\GiftCards;

class CardService extends \Stripe\Service\AbstractService {
	/**
	 * List gift cards for an account.
	 *
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Collection<\Stripe\GiftCards\Card>
	 */
	public function all($params = null, $opts = null) {
		return $this->requestCollection('get', '/v1/gift_cards/cards', $params, $opts);
	}

	/**
	 * Creates a new gift card object.
	 *
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\GiftCards\Card
	 */
	public function create($params = null, $opts = null) {
		return $this->request('post', '/v1/gift_cards/cards', $params, $opts);
	}

	/**
	 * Retrieve a gift card by id.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\GiftCards\Card
	 */
	public function retrieve($id, $params = null, $opts = null) {
		return $this->request('get', $this->buildPath('/v1/gift_cards/cards/%s', $id), $params, $opts);
	}

	/**
	 * Update a gift card.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\GiftCards\Card
	 */
	public function update($id, $params = null, $opts = null) {
		return $this->request('post', $this->buildPath('/v1/gift_cards/cards/%s', $id), $params, $opts);
	}

	/**
	 * Validates a gift card code, returning the matching gift card object if it
	 * exists.
	 *
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\GiftCards\Card
	 */
	public function validate($params = null, $opts = null) {
		return $this->request('post', '/v1/gift_cards/cards/validate', $params, $opts);
	}
}
