<?php

/**
 * Vvveb
 *
 * Copyright (C) 2022  Ziadin Givan
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

namespace Stripe\Service\Issuing;

class CreditUnderwritingRecordService extends \Stripe\Service\AbstractService {
	/**
	 * Retrieves a list of <code>CreditUnderwritingRecord</code> objects. The objects
	 * are sorted in descending order by creation date, with the most-recently-created
	 * object appearing first.
	 *
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Collection<\Stripe\Issuing\CreditUnderwritingRecord>
	 */
	public function all($params = null, $opts = null) {
		return $this->requestCollection('get', '/v1/issuing/credit_underwriting_records', $params, $opts);
	}

	/**
	 * Update a <code>CreditUnderwritingRecord</code> object to correct mistakes.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Issuing\CreditUnderwritingRecord
	 */
	public function correct($id, $params = null, $opts = null) {
		return $this->request('post', $this->buildPath('/v1/issuing/credit_underwriting_records/%s/correct', $id), $params, $opts);
	}

	/**
	 * Creates a <code>CreditUnderwritingRecord</code> object with information about a
	 * credit application submission.
	 *
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Issuing\CreditUnderwritingRecord
	 */
	public function createFromApplication($params = null, $opts = null) {
		return $this->request('post', '/v1/issuing/credit_underwriting_records/create_from_application', $params, $opts);
	}

	/**
	 * Creates a <code>CreditUnderwritingRecord</code> object from an underwriting
	 * decision coming from a proactive review of an existing accountholder.
	 *
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Issuing\CreditUnderwritingRecord
	 */
	public function createFromProactiveReview($params = null, $opts = null) {
		return $this->request('post', '/v1/issuing/credit_underwriting_records/create_from_proactive_review', $params, $opts);
	}

	/**
	 * Update a <code>CreditUnderwritingRecord</code> object from a decision made on a
	 * credit application.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Issuing\CreditUnderwritingRecord
	 */
	public function reportDecision($id, $params = null, $opts = null) {
		return $this->request('post', $this->buildPath('/v1/issuing/credit_underwriting_records/%s/report_decision', $id), $params, $opts);
	}

	/**
	 * Retrieves a <code>CreditUnderwritingRecord</code> object.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Issuing\CreditUnderwritingRecord
	 */
	public function retrieve($id, $params = null, $opts = null) {
		return $this->request('get', $this->buildPath('/v1/issuing/credit_underwriting_records/%s', $id), $params, $opts);
	}
}
