<?php

/**
 * Vvveb
 *
 * Copyright (C) 2022  Ziadin Givan
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

namespace Stripe\Service\Radar;

class ValueListItemService extends \Stripe\Service\AbstractService {
	/**
	 * Returns a list of <code>ValueListItem</code> objects. The objects are sorted in
	 * descending order by creation date, with the most recently created object
	 * appearing first.
	 *
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Collection<\Stripe\Radar\ValueListItem>
	 */
	public function all($params = null, $opts = null) {
		return $this->requestCollection('get', '/v1/radar/value_list_items', $params, $opts);
	}

	/**
	 * Creates a new <code>ValueListItem</code> object, which is added to the specified
	 * parent value list.
	 *
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Radar\ValueListItem
	 */
	public function create($params = null, $opts = null) {
		return $this->request('post', '/v1/radar/value_list_items', $params, $opts);
	}

	/**
	 * Deletes a <code>ValueListItem</code> object, removing it from its parent value
	 * list.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Radar\ValueListItem
	 */
	public function delete($id, $params = null, $opts = null) {
		return $this->request('delete', $this->buildPath('/v1/radar/value_list_items/%s', $id), $params, $opts);
	}

	/**
	 * Retrieves a <code>ValueListItem</code> object.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Radar\ValueListItem
	 */
	public function retrieve($id, $params = null, $opts = null) {
		return $this->request('get', $this->buildPath('/v1/radar/value_list_items/%s', $id), $params, $opts);
	}
}
