<?php

/**
 * Vvveb
 *
 * Copyright (C) 2022  Ziadin Givan
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

namespace Stripe\Service;

class ReviewService extends \Stripe\Service\AbstractService {
	/**
	 * Returns a list of <code>Review</code> objects that have <code>open</code> set to
	 * <code>true</code>. The objects are sorted in descending order by creation date,
	 * with the most recently created object appearing first.
	 *
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Collection<\Stripe\Review>
	 */
	public function all($params = null, $opts = null) {
		return $this->requestCollection('get', '/v1/reviews', $params, $opts);
	}

	/**
	 * Approves a <code>Review</code> object, closing it and removing it from the list
	 * of reviews.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Review
	 */
	public function approve($id, $params = null, $opts = null) {
		return $this->request('post', $this->buildPath('/v1/reviews/%s/approve', $id), $params, $opts);
	}

	/**
	 * Retrieves a <code>Review</code> object.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Review
	 */
	public function retrieve($id, $params = null, $opts = null) {
		return $this->request('get', $this->buildPath('/v1/reviews/%s', $id), $params, $opts);
	}
}
