<?php

/**
 * Vvveb
 *
 * Copyright (C) 2022  Ziadin Givan
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

namespace Stripe\Service;

class ShippingRateService extends \Stripe\Service\AbstractService {
	/**
	 * Returns a list of your shipping rates.
	 *
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Collection<\Stripe\ShippingRate>
	 */
	public function all($params = null, $opts = null) {
		return $this->requestCollection('get', '/v1/shipping_rates', $params, $opts);
	}

	/**
	 * Creates a new shipping rate object.
	 *
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\ShippingRate
	 */
	public function create($params = null, $opts = null) {
		return $this->request('post', '/v1/shipping_rates', $params, $opts);
	}

	/**
	 * Returns the shipping rate object with the given ID.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\ShippingRate
	 */
	public function retrieve($id, $params = null, $opts = null) {
		return $this->request('get', $this->buildPath('/v1/shipping_rates/%s', $id), $params, $opts);
	}

	/**
	 * Updates an existing shipping rate object.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\ShippingRate
	 */
	public function update($id, $params = null, $opts = null) {
		return $this->request('post', $this->buildPath('/v1/shipping_rates/%s', $id), $params, $opts);
	}
}
