<?php

/**
 * Vvveb
 *
 * Copyright (C) 2022  Ziadin Givan
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

namespace Stripe\Service\Tax;

class TransactionService extends \Stripe\Service\AbstractService {
	/**
	 * Retrieves the line items of a committed standalone transaction as a collection.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Collection<\Stripe\Tax\TransactionLineItem>
	 */
	public function allLineItems($id, $params = null, $opts = null) {
		return $this->requestCollection('get', $this->buildPath('/v1/tax/transactions/%s/line_items', $id), $params, $opts);
	}

	/**
	 * Creates a Tax <code>Transaction</code> from a calculation.
	 *
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Tax\Transaction
	 */
	public function createFromCalculation($params = null, $opts = null) {
		return $this->request('post', '/v1/tax/transactions/create_from_calculation', $params, $opts);
	}

	/**
	 * Partially or fully reverses a previously created <code>Transaction</code>.
	 *
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Tax\Transaction
	 */
	public function createReversal($params = null, $opts = null) {
		return $this->request('post', '/v1/tax/transactions/create_reversal', $params, $opts);
	}

	/**
	 * Retrieves a Tax <code>Transaction</code> object.
	 *
	 * @param string $id
	 * @param null|array $params
	 * @param null|array|\Stripe\Util\RequestOptions $opts
	 *
	 * @throws \Stripe\Exception\ApiErrorException if the request fails
	 *
	 * @return \Stripe\Tax\Transaction
	 */
	public function retrieve($id, $params = null, $opts = null) {
		return $this->request('get', $this->buildPath('/v1/tax/transactions/%s', $id), $params, $opts);
	}
}
